@@ -1,4 +1,4 @@
-"""Climate object """
+"""Light object """
 
 from typing import Union
 
